==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/tr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Yedek kodlar oluşturulurken bir sorun çıktı",
    "{name} backup codes" : "{name} yedek kodları",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Yedek kodlarınızı burada görebilirsiniz. Kodları daha sonra göremeyeceğiniz için bu kodları kaydedin ya da yazdırın",
    "Save backup codes" : "Yedek kodları kaydet",
    "Print backup codes" : "Yedek kodları yazdır",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Yedek kodları oluşturuldu.  {used} / {total} kod kullanılıyor.",
    "Regenerate backup codes" : "Yedek kodlarını yeniden oluştur",
    "_icon-loading-small_::_generate-backup-codes_" : ["simge-yukleniyor-kucuk","yedek-kodlari-olustur"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Yedek kodlarını yeniden oluşturursanız, eski kodlar geçersiz olur.",
    "Generate backup codes" : "Yedek kodları oluştur",
    "You created two-factor backup codes for your account" : "İki aşamalı kimlik doğrulama için yedek kodlarınızı oluşturdunuz",
    "Second-factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "İki aşamalı kimlik doğrulamasını etkinleştirmiş ancak yedek kodlarını üretmemişsiniz. İkinci aşamaya erişemediğiniz zaman kullanabilmek için yedek kodlarını üretmeyi unutmayın.",
    "Backup code" : "Yedek kod",
    "Use backup code" : "Yedek kodu kullan",
    "Two factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "A two-factor auth backup codes provider" : "İki aşamalı kimlik doğrulaması için yedek kodlar sağlayıcısı",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "İki aşamalı kimlik doğrulamasını ayarlarken yedek kodlarından birini kullanın.",
    "Submit" : "Gönder",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Yedek kodları oluşturuldu. {{used}} / {{total}} kod kullanılıyor.",
    "Nextcloud backup codes" : "Nextcloud yedek kodları",
    "activated" : "etkinleştirildi",
    "updated" : "güncellendi",
    "mounted" : "bağlandı",
    "deactivated" : "devre dışı bırakıldı",
    "beforeCreate" : "eklenmedenOnce",
    "created" : "eklenme",
    "beforeUpdate" : "guncellenmedenOnce",
    "beforeDestroy" : "yokEdilmedenOnce",
    "destroyed" : "yokEdildi",
    "beforeMount" : "baglanmadanOnce"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/tr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Yedek kodlar oluşturulurken bir sorun çıktı",
    "{name} backup codes" : "{name} yedek kodları",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Yedek kodlarınızı burada görebilirsiniz. Kodları daha sonra göremeyeceğiniz için bu kodları kaydedin ya da yazdırın",
    "Save backup codes" : "Yedek kodları kaydet",
    "Print backup codes" : "Yedek kodları yazdır",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Yedek kodları oluşturuldu.  {used} / {total} kod kullanılıyor.",
    "Regenerate backup codes" : "Yedek kodlarını yeniden oluştur",
    "_icon-loading-small_::_generate-backup-codes_" : ["simge-yukleniyor-kucuk","yedek-kodlari-olustur"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Yedek kodlarını yeniden oluşturursanız, eski kodlar geçersiz olur.",
    "Generate backup codes" : "Yedek kodları oluştur",
    "You created two-factor backup codes for your account" : "İki aşamalı kimlik doğrulama için yedek kodlarınızı oluşturdunuz",
    "Second-factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "İki aşamalı kimlik doğrulamayı etkinleştirdiniz ancak henüz yedek kodlarını üretmediniz. Bu kodlar herhangi bir nedenle ikinci aşamayı kullanamadığınızda hesabınıza erişebilmenizi sağlar.",
    "Backup code" : "Yedek kod",
    "Use backup code" : "Yedek kodu kullan",
    "Two factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "A two-factor auth backup codes provider" : "İki aşamalı kimlik doğrulaması için yedek kodlar sağlayıcısı",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "İki aşamalı kimlik doğrulamasını ayarlarken yedek kodlarından birini kullanın.",
    "Submit" : "Gönder",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Yedek kodları oluşturuldu. {{used}} / {{total}} kod kullanılıyor.",
    "Nextcloud backup codes" : "Nextcloud yedek kodları",
    "activated" : "etkinleştirildi",
    "updated" : "güncellendi",
    "mounted" : "bağlandı",
    "deactivated" : "devre dışı bırakıldı",
    "beforeCreate" : "eklenmedenOnce",
    "created" : "eklenme",
    "beforeUpdate" : "guncellenmedenOnce",
    "beforeDestroy" : "yokEdilmedenOnce",
    "destroyed" : "yokEdildi",
    "beforeMount" : "baglanmadanOnce",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "İki aşamalı kimlik doğrulamasını etkinleştirmiş ancak yedek kodlarını üretmemişsiniz. İkinci aşamaya erişemediğiniz zaman kullanabilmek için yedek kodlarını üretmeyi unutmayın."
},
"nplurals=2; plural=(n > 1);");
